@@ -125,14 +125,21 @@ def catalog_view(request):
 
     try:
         app_catalog = locale.translations._domains[domain]
+    except KeyError:
+        logger.warning('Could not find "%s" translation catalog for "%s",'
+                       ' maybe it has not been compiled? Falling back to'
+                       ' the "native" language.', domain, name)
+        app_catalog = None
+
+    try:
         desktop_catalog = locale.translations._domains['mp-desktop']
     except KeyError:
-        # Usually the "en" language is native, no external catalog
-        # exists for it
-        if name != 'en':
-            logger.warning('Could not find "%s" translation catalog for "%s",'
-                           ' maybe it has not been compiled? Falling back to'
-                           ' "en".', domain, name)
+        logger.warning('Could not find "%s" translation catalog for "%s",'
+                       ' maybe it has not been compiled? Falling back to'
+                       ' "native" language.', "mp-desktop", name)
+        desktop_catalog = None
+
+    if app_catalog is desktop_catalog is None:
         name = 'en'
         plural_forms = '(n != 1)'
         msgs = {}
@@ -156,7 +163,7 @@ def _massage_catalog(app_catalog, desktop_catalog):
     from re import match
     from itertools import chain
 
-    cinfo = app_catalog.info()
+    cinfo = (app_catalog or desktop_catalog).info()
 
     pforms = match(r'\s*nplurals\s*=\s*[0-9]+\s*;\s*'
                    r'plural\s*=\s*(\(.+\))\s*;?\s*$',
@@ -168,8 +175,10 @@ def _massage_catalog(app_catalog, desktop_catalog):
     msgs = {}
 
     entries = {}
-    for m, t in chain(app_catalog._catalog.items(),
-                      desktop_catalog._catalog.items()):
+    for m, t in chain(app_catalog._catalog.items()
+                      if app_catalog is not None else (),
+                      desktop_catalog._catalog.items()
+                      if desktop_catalog is not None else ()):
         # Skip the "empty" key, as it is used for the catalog metadata
         if m:
             # Pluralizable messages have (singular,0), (singular,1) and
